#%%global rc_ver 2
%global baserelease 3
%global maj_ver		11
%global min_ver		0
%global patch_ver	1
%global mlir_srcdir	llvm-project-%{version}%{?rc_ver:rc%{rc_ver}}.src

%define major	%{maj_ver}.%{min_ver}
%define minor	1

%define libname %mklibname mlir %{major}
%define devname %mklibname -d mlir

Name:		mlir
Version:	%{maj_ver}.%{min_ver}.%{patch_ver}
Release:	%mkrel %{baserelease}%{?rc_ver:.rc%{rc_ver}}.1
Summary:	Multi-Level Intermediate Representation Overview
Group:		Development/Other
License:	ASL 2.0 with exceptions
URL:		http://mlir.llvm.org
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{mlir_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{mlir_srcdir}.tar.xz.sig
Source2:	tstellar-gpg-key.asc
# Support standalone build (MLIR is usually built as part of LLVM)
Patch0:		mlir-cmake-standalone.patch
BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	zlib-devel
BuildRequires:	llvm-devel = %{version}
BuildRequires:	llvm-test = %{version}

# For origin certification
BuildRequires:	gnupg2


%description
The MLIR project is a novel approach to building reusable and
extensible compiler infrastructure. MLIR aims to address software
fragmentation, improve compilation for heterogeneous hardware,
significantly reduce the cost of building domain specific compilers,
and aid in connecting existing compilers together.

%package -n %libname
Summary:	Runtime librariesy for MLIR
Group:		Development/Other

%description -n %libname
The MLIR project is a novel approach to building reusable and
extensible compiler infrastructure. MLIR aims to address software
fragmentation, improve compilation for heterogeneous hardware,
significantly reduce the cost of building domain specific compilers,
and aid in connecting existing compilers together.

This package contains the runtime libraries for MLIR.

	
%package -n %devname
Summary:	Development header files for MLIR
Group:		Development/Other
Provides:	mlir-devel = %version-%release
Requires:	%{libname} = %{version}-%{release}
	
%description -n %devname
Development header files for MLIR.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{mlir_srcdir}/%{name} -p2
# remove all but keep mlir
find ../* -maxdepth 0 ! -name '%{name}' -exec rm -rf {} +

%build
%cmake \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_BUILD_UTILS:BOOL=ON \
	-DMLIR_INCLUDE_DOCS:BOOL=ON \
	-DMLIR_INCLUDE_TESTS:BOOL=OFF \
	-DMLIR_INCLUDE_INTEGRATION_TESTS:BOOL=OFF \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif
# build process .exe tools normally use rpath or static linkage
export LD_LIBRARY_PATH=$(pwd)/%{_vpath_builddir}/bin
%cmake_build

%install
%cmake_install

%check
# build process .exe tools normally use rpath or static linkage
%cmake_build --target check-mlir || true

%files -n %libname
%license LICENSE.TXT
%{_libdir}/libMLIR*.so.%{maj_ver}{,.*}
%{_libdir}/libmlir_runner_utils.so.%{maj_ver}{,.*}
%{_libdir}/libmlir_c_runner_utils.so.%{maj_ver}{,.*}
%{_libdir}/libmlir_c_runner_utils_static.so.%{maj_ver}{,.*}
	
%files -n %devname
%{_bindir}/mlir-tblgen
%{_libdir}/libMLIR*.so
%{_libdir}/libmlir_runner_utils.so
%{_libdir}/libmlir_c_runner_utils.so
%{_libdir}/libmlir_c_runner_utils_static.so
%{_includedir}/mlir
%{_includedir}/mlir-c
%{_libdir}/cmake/*
%{_libdir}/libMLIR*.a


%changelog
* Thu Jan 07 2021 tv <tv> 11.0.1-3.1.mga8
+ Revision: 1669534
- LLVM 11.0.1 final

* Thu Dec 31 2020 ghibo <ghibo> 11.0.1-0.rc2.1.mga8
+ Revision: 1667284
- Update to release 11.0.1rc2

* Thu Dec 03 2020 ghibo <ghibo> 11.0.1-0.rc1.1.mga8
+ Revision: 1652043
- Fix Requires

* Wed Dec 02 2020 ghibo <ghibo> 11.0.1-0.rc1.mga8
+ Revision: 1651820
- Fix baserelease
- Sync to release 11.0.1-rc1

* Wed Dec 02 2020 ghibo <ghibo> 11.0.0-2.mga8
+ Revision: 1651723
- Fix Requires

* Wed Dec 02 2020 ghibo <ghibo> 11.0.0-1.mga8
+ Revision: 1651638
- imported package mlir

